==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/FinancialOverlayDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { FinancialSeriesDescription } from "./FinancialSeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var FinancialOverlayDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinancialOverlayDescription, _super);
    function FinancialOverlayDescription() {
        var _this = _super.call(this) || this;
        _this.dx = 0;
        return _this;
    }
    FinancialOverlayDescription.prototype.get_type = function () {
        return "FinancialOverlay";
    };
    Object.defineProperty(FinancialOverlayDescription.prototype, "ignoreFirst", {
        get: function () {
            return this.dx;
        },
        set: function (a) {
            this.dx = a;
            this.e("IgnoreFirst");
        },
        enumerable: false,
        configurable: true
    });
    FinancialOverlayDescription.$t = markType(FinancialOverlayDescription, 'FinancialOverlayDescription', FinancialSeriesDescription.$);
    return FinancialOverlayDescription;
}(FinancialSeriesDescription));
export { FinancialOverlayDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/FinancialOverlayDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { FinancialSeriesDescription } from "./FinancialSeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var FinancialOverlayDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinancialOverlayDescription, _super);
    function FinancialOverlayDescription() {
        var _this = _super.call(this) || this;
        _this.f7 = 0;
        return _this;
    }
    FinancialOverlayDescription.prototype.get_type = function () {
        return "FinancialOverlay";
    };
    Object.defineProperty(FinancialOverlayDescription.prototype, "ignoreFirst", {
        get: function () {
            return this.f7;
        },
        set: function (a) {
            this.f7 = a;
            this.g("IgnoreFirst");
        },
        enumerable: false,
        configurable: true
    });
    FinancialOverlayDescription.$t = markType(FinancialOverlayDescription, 'FinancialOverlayDescription', FinancialSeriesDescription.$);
    return FinancialOverlayDescription;
}(FinancialSeriesDescription));
export { FinancialOverlayDescription };
